Change Log
==========

All notable changes to this project will be documented in this file.
This project adheres to `Semantic Versioning <http://semver.org/>`__.

[Unreleased]
------------

[1.0] - 2016-06-19
------------------

- First prototype from existing HMS services
